;; Simple hello world
;;
;; expect output:
;;; Hello,world!!
(trace "Hello,world!!")